@@ -14,7 +14,7 @@ use version;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.087'; # VERSION
+our $VERSION = '0.088'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -156,21 +156,8 @@ sub release {
 
     for my $root ( @{ $self->live_roots } ) {
 
-        my @args = (
-            -root     => $root,
-            -message  => "Added " . $archive->basename,
-
-            $self->authenticate ? (-username => $self->username) : (),
-            $self->authenticate ? (-password => $self->password) : (),
-            $self->has_recurse  ? (-recurse  => $self->recurse)  : (),
-            $self->has_author   ? (-author   => $self->author)   : (),
-            $self->has_stack    ? (-stack    => $self->stack)    : (),
-
-            $archive,
-        );
-
-
         $self->log("adding $archive to repository at $root");
+        my @args = $self->_generate_pinto_args($root, $archive);
         my ($ok, $output) = $self->_run_pinto( add => @args );
 
         $ok ? $self->log("added $archive to $root ok")
@@ -182,6 +169,28 @@ sub release {
 
 #------------------------------------------------------------------------------
 
+sub _generate_pinto_args {
+    my ($self, $root, $archive) = @_;
+
+    my @recurse_opt = $self->has_recurse
+        ? ($self->recurse ? qw(-recurse) : qw(-no-recurse))  : ();
+
+    return (
+        -root     => $root,
+        -message  => "Added " . $archive->basename,
+
+        $self->authenticate ? (-username => $self->username) : (),
+        $self->authenticate ? (-password => $self->password) : (),
+        $self->has_stack    ? (-stack    => $self->stack)    : (),
+        @recurse_opt,
+
+        $archive,
+    );
+
+}
+
+#------------------------------------------------------------------------------
+
 sub _ask_for_password {
     my ($self) = @_;
 
@@ -242,7 +251,7 @@ Dist::Zilla::Plugin::Pinto::Add - Ship your dist to a Pinto repository
 
 =head1 VERSION
 
-version 0.087
+version 0.088
 
 =head1 SYNOPSIS
 
